@@ -28,7 +28,7 @@ from sushy import utils
 LOG = logging.getLogger(__name__)
 
 
-_SERVER_SIDE_RETRIES = 5
+_SERVER_SIDE_RETRIES = 10
 _SERVER_SIDE_RETRY_DELAY = 3
 
 
@@ -86,6 +86,15 @@ class Connector(object):
         """Close this connector and the associated HTTP session."""
         self._session.close()
 
+    def check_retry_on_exception(self, exception_msg):
+        """Checks whether retry on exception is required."""
+        if ('SYS518' in str(exception_msg)):
+            LOG.debug('iDRAC is not yet ready after previous operation. '
+                      'Error: %(err)s', {'err': str(exception_msg)})
+            return True
+        else:
+            return False
+
     def _op(self, method, path='', data=None, headers=None, blocking=False,
             timeout=60, server_side_retries=_SERVER_SIDE_RETRIES,
             **extra_session_req_kwargs):
@@ -97,7 +106,11 @@ class Connector(object):
         :param data: Optional JSON data.
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
-        :param timeout: Max time in seconds to wait for blocking async call.
+        :param timeout: Max time in seconds to wait for blocking async call or
+                        for requests library to connect and read. If a custom
+                        timeout for requests is provided in
+                        extra_session_req_kwargs, it will be used instead for
+                        those calls.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -126,6 +139,7 @@ class Connector(object):
         try:
             response = self._session.request(method, url, json=data,
                                              headers=headers,
+                                             timeout=timeout,
                                              **extra_session_req_kwargs)
         except requests.exceptions.RequestException as e:
             # Capture any general exception by looking for the parent
@@ -183,6 +197,7 @@ class Connector(object):
                     response = self._session.request(
                         method, url, json=data,
                         headers=headers,
+                        timeout=timeout,
                         **extra_session_req_kwargs)
                 except exceptions.HTTPError as retry_exc:
                     LOG.error("Failure occured while attempting to retry "
@@ -199,9 +214,9 @@ class Connector(object):
                               "%s", e.message)
                 raise
         except exceptions.ServerSideError as e:
-            if method.lower() != 'get' or server_side_retries <= 0:
-                raise
-            else:
+            if ((method.lower() == 'get'
+                or self.check_retry_on_exception(e.message))
+                    and server_side_retries > 0):
                 LOG.warning('Got server side error %s in response to a '
                             'GET request, retrying after %d seconds',
                             e, _SERVER_SIDE_RETRY_DELAY)
@@ -210,6 +225,8 @@ class Connector(object):
                                 blocking=blocking, timeout=timeout,
                                 server_side_retries=server_side_retries - 1,
                                 **extra_session_req_kwargs)
+            else:
+                raise
 
         if blocking and response.status_code == 202:
             if not response.headers.get('Location'):
